@@ -114,6 +114,7 @@ class Client:
 
         self.__response_guard = threading.Lock()
         self.__response_status = None
+        self.__response_message = None
         self.__response_body = None
         self.__response_headers = None
 
@@ -228,6 +229,7 @@ class Client:
 
             with self.__response_guard:
                 self.__response_status = server_response.status
+                self.__response_message = server_response.msg
                 self.__response_headers = server_response.headers
                 self.__response_body = server_response.read().decode('utf-8')
 
@@ -243,10 +245,11 @@ class Client:
             server_response = connection.getresponse()
 
             with self.__event_queue:
-                response = Response(server_response.status, server_response.read().decode('utf-8'),
-                                    server_response.headers)
+                response_instance = Response(server_response.status, server_response.reason,
+                                             server_response.read().decode('utf-8'),
+                                             server_response.headers)
 
-                self.__async_queue[connection] = response
+                self.__async_queue[connection] = response_instance
                 self.__event_queue.notify_all()
 
         except Exception as exception:
@@ -439,6 +442,13 @@ class Client:
             return status
 
 
+    def get_response_message(self):
+        with self.__response_guard:
+            message = self.__response_message
+            self.__response_message = None
+            return message
+
+
     def get_response_headers(self):
         """
 
@@ -562,6 +572,36 @@ class Client:
         return response.get_status()
 
 
+    def get_reason_from_response(self, response):
+        """
+
+        Return response reason as a string from the specified response object that was obtained by function
+        'Get Async Response'. For example, response code and reason are '200 OK', in this case 'OK' is going
+        to be returned by this function.
+
+        Example how to get response reason from a response object:
+
+        +---------------------+--------------------------+-------------+
+        | ${response reason}= | Get Reason From Response | ${response} |
+        +---------------------+--------------------------+-------------+
+
+        .. code:: text
+
+            ${connection}=      Send HTTP Async Request   GET             /get
+
+            # Some other actions ...
+
+            ${response}=          Get Async Response         ${connection}   5
+            ${response reason}=   Get Reason From Response   ${response}
+
+        """
+        if response is None:
+            logger.error("Impossible to get reason from 'None' response object.")
+            return None
+
+        return response.get_reason()
+
+
     def get_headers_from_response(self, response):
         """
 
@@ -1077,7 +1117,7 @@ class Server:
         Send response using specified HTTP code and body. This function should be called after \`Wait For Request\`.
 
         `status` [in] (string): HTTP status code for response.
-        `body` [in] (string): Body that should contain response.
+        `body` [in] (string|bytes): Body that should contain response.
 
         Example how to reply by 204 (No Content) to incoming request:
 
@@ -1100,10 +1140,18 @@ class Server:
             ${response body}=   Set Variable   { "status": "accepted" }
             Reply By   204   ${response body}
 
-        """
-        response = Response(int(status), body, self.__response_headers)
-        ResponseStorage().push(response)
+        Example how to reply with a body represented by a sequence of bytes:
 
+        ..code:: text
+
+            Wait For Request
+
+            ${body bytes}=   Evaluate   bytes((0x0a, 0x12, 0x0a))
+            Reply By   200   ${body bytes}
+
+        """
+        response = Response(int(status), None, body, self.__response_headers)
+        ResponseStorage().push(response)
 
 
 class Json:
